@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * Authors: Carlos Garnacho Parro  <carlosg@gnome.org>
  */
@@ -93,15 +93,13 @@ gst_network_locations_class_init (GstNetworkLocationsClass *class)
 			    sizeof (GstNetworkLocationsPrivate));
 }
 
-#define MATE_DOT_MATE ".mate2/"
-
 static gchar*
 create_dot_dir ()
 {
   gchar *dir;
 
-  dir = g_build_filename (g_get_home_dir (),
-			  MATE_DOT_MATE,
+  dir = g_build_filename (g_get_user_config_dir (),
+			  "mate",
 			  "network-admin-locations",
 			  NULL);
 
